#!/usr/bin/env node
"use strict";
/*
 * MIT License
 *
 * Copyright (c) 2018 Choko (choko@curioswitch.org)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const eslint_1 = require("eslint");
const tslint_1 = require("tslint");
const typescript_1 = __importDefault(require("typescript"));
const test_1 = __importDefault(require("./test"));
class FormatTypescriptHost {
    getCurrentDirectory() {
        return process.cwd();
    }
    getCanonicalFileName(fileName) {
        return fileName;
    }
    getNewLine() {
        return '\n';
    }
}
function lint(fix) {
    const program = tslint_1.Linter.createProgram(path_1.default.resolve(process.cwd(), 'tsconfig.json'), process.cwd());
    const diagnostics = [
        ...program.getSemanticDiagnostics(),
        ...program.getSyntacticDiagnostics(),
    ];
    if (diagnostics.length > 0) {
        console.log(typescript_1.default.formatDiagnosticsWithColorAndContext(diagnostics, new FormatTypescriptHost()));
        process.exit(1);
    }
    const lintCli = new eslint_1.CLIEngine({
        fix: !!fix,
        extensions: ['.js', '.jsx', '.ts', '.tsx'],
        ignorePattern: ['*.d.ts'],
    });
    const report = lintCli.executeOnFiles(['src/']);
    console.log(lintCli.getFormatter()(report.results));
    return report.errorCount === 0;
}
exports.lint = lint;
function check() {
    return __awaiter(this, void 0, void 0, function* () {
        const result = yield lint();
        if (!result) {
            throw new Error('Lint failed.');
        }
        return test_1.default();
    });
}
exports.check = check;
if (require.main === module) {
    check().catch(() => process.exit(1));
}
//# sourceMappingURL=check.js.map